##
##  webhook.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_webhook_base 2.8.1
%define       V_webhook_snap 20230806

#   package information
Name:         webhook
Summary:      Web Hook Daemon
URL:          https://github.com/adnanh/webhook/
Vendor:       Adnan Hajdarevic
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Web
License:      MIT
Version:      %{V_webhook_base}.%{V_webhook_snap}
Release:      20230806

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/webhook/webhook-%{V_webhook_snap}.tar.xz
Source1:      hooks.json
Source2:      rc.webhook
Source3:      sample.sh

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    webhook is a lightweight configurable tool written in Go, that
    allows you to easily create HTTP endpoints (hooks) on your server,
    which you can use to execute configured commands. You can also
    pass data from the HTTP request (such as headers, payload or query
    variables) to your commands. webhook also allows you to specify
    rules which have to be satisfied in order for the hook to be
    triggered.

%track
    prog webhook:release = {
        version   = %{V_webhook_base}
        url       = https://github.com/adnanh/webhook/releases
        regex     = (\d+\.\d+\.\d+)\.tar\.gz
    }
    prog webhook:snapshot = {
        version   = %{V_webhook_snap}
        url       = http://download.openpkg.org/components/versioned/webhook/
        regex     = webhook-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n webhook

%build
    #   build program
    export GOPATH=`pwd`
    cd src/github.com/adnanh/webhook
    go build -v -o webhook

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/webhook \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/webhook \
        $RPM_BUILD_ROOT%{l_prefix}/var/webhook/log \
        $RPM_BUILD_ROOT%{l_prefix}/var/webhook/run

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/adnanh/webhook/webhook \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/

    #   install configuration
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE hooks.json} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/webhook/

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.webhook} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install sample hook
    %{l_shtool} install -c -m 755 \
        %{SOURCE sample.sh} \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/webhook/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/webhook' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/webhook/*'

%files -f files

%clean

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} webhook status 2>/dev/null`
    [ ".$webhook_active" = .yes ] && %{l_rc} webhook restart
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} webhook stop 2>/dev/null
    rm -rf $RPM_INSTALL_PREFIX/var/webhook/log/* >/dev/null 2>&1 || true
    rm -rf $RPM_INSTALL_PREFIX/var/webhook/run/* >/dev/null 2>&1 || true
    exit 0

